##  Salesforce (PaaS)
Platform-as-a-Service (PaaS) is a proven model for running applications without the hassle of maintaining on-premise hardware or software infrastructure at your company. The built-in features and functionality take care of back-end concerns such as security, infrastructure, and data integration so that you can focus on building your apps faster. The following diagram shows an example of how to model Salesforce as a PaaS solution in SAP LeanIX:
![1892](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27493c617a441014b1bab18a3e8a386e_LowRes.png)
YesNo
Send
